@@ -57,7 +57,7 @@ var _ = g.Describe("[sig-instrumentation][Late] Alerts", func() {
 		}
 		oc.SetupProject()
 		ns := oc.Namespace()
-		execPod := exutil.CreateCentosExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
+		execPod := exutil.CreateUbiExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
 		defer func() {
 			oc.AdminKubeClient().CoreV1().Pods(ns).Delete(context.Background(), execPod.Name, *metav1.NewDeleteOptions(1))
 		}()
@@ -74,7 +74,7 @@ var _ = g.Describe("[sig-instrumentation][Late] Alerts", func() {
 	g.It("should have a Watchdog alert in firing state the entire cluster run", func() {
 		oc.SetupProject()
 		ns := oc.Namespace()
-		execPod := exutil.CreateCentosExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
+		execPod := exutil.CreateUbiExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
 		defer func() {
 			oc.AdminKubeClient().CoreV1().Pods(ns).Delete(context.Background(), execPod.Name, *metav1.NewDeleteOptions(1))
 		}()
@@ -95,7 +95,7 @@ var _ = g.Describe("[sig-instrumentation][Late] Alerts", func() {
 		oc.SetupProject()
 		ns := oc.Namespace()
 
-		execPod := exutil.CreateCentosExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
+		execPod := exutil.CreateUbiExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
 		defer func() {
 			oc.AdminKubeClient().CoreV1().Pods(ns).Delete(context.Background(), execPod.Name, *metav1.NewDeleteOptions(1))
 		}()
@@ -136,7 +136,7 @@ var _ = g.Describe("[sig-instrumentation] Prometheus", func() {
 			oc.SetupProject()
 			ns := oc.Namespace()
 
-			execPod := exutil.CreateCentosExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
+			execPod := exutil.CreateUbiExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
 			defer func() {
 				oc.AdminKubeClient().CoreV1().Pods(ns).Delete(context.Background(), execPod.Name, *metav1.NewDeleteOptions(1))
 			}()
@@ -160,7 +160,7 @@ var _ = g.Describe("[sig-instrumentation] Prometheus", func() {
 		g.It("should start and expose a secured proxy and unsecured metrics", func() {
 			oc.SetupProject()
 			ns := oc.Namespace()
-			execPod := exutil.CreateCentosExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
+			execPod := exutil.CreateUbiExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
 			defer func() {
 				oc.AdminKubeClient().CoreV1().Pods(ns).Delete(context.Background(), execPod.Name, *metav1.NewDeleteOptions(1))
 			}()
@@ -232,8 +232,7 @@ var _ = g.Describe("[sig-instrumentation] Prometheus", func() {
 						targets.Expect(labels{"job": "kube-state-metrics"}, "up", "^https://.*/metrics$"),
 
 						// Cluster version operator
-						// TODO: should probably be https
-						targets.Expect(labels{"job": "cluster-version-operator"}, "up", "^http://.*/metrics$"),
+						targets.Expect(labels{"job": "cluster-version-operator"}, "up", "^https://.*/metrics$"),
 					)
 				}
 
@@ -263,20 +262,12 @@ var _ = g.Describe("[sig-instrumentation] Prometheus", func() {
 			o.Expect(err).NotTo(o.HaveOccurred())
 
 			// Currently following targets do not secure their /metrics endpoints:
-			// job="cco-metrics" - https://bugzilla.redhat.com/show_bug.cgi?id=1809194
-			// job="cluster-version-operator" - https://bugzilla.redhat.com/show_bug.cgi?id=1809195
 			// job="crio" - https://issues.redhat.com/browse/MON-1034 + https://issues.redhat.com/browse/OCPNODE-321
-			// job="sdn" - https://bugzilla.redhat.com/show_bug.cgi?id=1809205
-			// job="multus-admission-controller-monitor-service" - https://bugzilla.redhat.com/show_bug.cgi?id=1809204
 			// job="ovnkube-master" - https://issues.redhat.com/browse/SDN-912
 			// job="ovnkube-node" - https://issues.redhat.com/browse/SDN-912
 			// Exclude list should be reduced to 0
 			exclude := map[string]bool{
-				"cco-metrics":              true,
-				"cluster-version-operator": true,
-				"crio":                     true,
-				"sdn":                      true,
-				"multus-admission-controller-monitor-service": true,
+				"crio":           true,
 				"ovnkube-master": true,
 				"ovnkube-node":   true,
 			}
@@ -296,7 +287,7 @@ var _ = g.Describe("[sig-instrumentation] Prometheus", func() {
 		g.It("should have a AlertmanagerReceiversNotConfigured alert in firing state", func() {
 			oc.SetupProject()
 			ns := oc.Namespace()
-			execPod := exutil.CreateCentosExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
+			execPod := exutil.CreateUbiExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
 			defer func() {
 				oc.AdminKubeClient().CoreV1().Pods(ns).Delete(context.Background(), execPod.Name, *metav1.NewDeleteOptions(1))
 			}()
@@ -311,7 +302,7 @@ var _ = g.Describe("[sig-instrumentation] Prometheus", func() {
 		g.It("should have important platform topology metrics", func() {
 			oc.SetupProject()
 			ns := oc.Namespace()
-			execPod := exutil.CreateCentosExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
+			execPod := exutil.CreateUbiExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
 			defer func() {
 				oc.AdminKubeClient().CoreV1().Pods(ns).Delete(context.Background(), execPod.Name, *metav1.NewDeleteOptions(1))
 			}()
@@ -336,7 +327,7 @@ var _ = g.Describe("[sig-instrumentation] Prometheus", func() {
 		g.It("should have non-Pod host cAdvisor metrics", func() {
 			oc.SetupProject()
 			ns := oc.Namespace()
-			execPod := exutil.CreateCentosExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
+			execPod := exutil.CreateUbiExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
 			defer func() {
 				oc.AdminKubeClient().CoreV1().Pods(ns).Delete(context.Background(), execPod.Name, *metav1.NewDeleteOptions(1))
 			}()
@@ -349,7 +340,7 @@ var _ = g.Describe("[sig-instrumentation] Prometheus", func() {
 		g.It("shouldn't have failing rules evaluation", func() {
 			oc.SetupProject()
 			ns := oc.Namespace()
-			execPod := exutil.CreateCentosExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
+			execPod := exutil.CreateUbiExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
 			defer func() {
 				oc.AdminKubeClient().CoreV1().Pods(ns).Delete(context.Background(), execPod.Name, *metav1.NewDeleteOptions(1))
 			}()
@@ -363,7 +354,7 @@ var _ = g.Describe("[sig-instrumentation] Prometheus", func() {
 			g.It("should be able to get the sdn ovs flows", func() {
 				oc.SetupProject()
 				ns := oc.Namespace()
-				execPod := exutil.CreateCentosExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
+				execPod := exutil.CreateUbiExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
 				defer func() {
 					oc.AdminKubeClient().CoreV1().Pods(ns).Delete(context.Background(), execPod.Name, *metav1.NewDeleteOptions(1))
 				}()
@@ -381,7 +372,7 @@ var _ = g.Describe("[sig-instrumentation] Prometheus", func() {
 			}
 			oc.SetupProject()
 			ns := oc.Namespace()
-			execPod := exutil.CreateCentosExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
+			execPod := exutil.CreateUbiExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
 			defer func() {
 				oc.AdminKubeClient().CoreV1().Pods(ns).Delete(context.Background(), execPod.Name, *metav1.NewDeleteOptions(1))
 			}()
@@ -396,7 +387,7 @@ var _ = g.Describe("[sig-instrumentation] Prometheus", func() {
 			oc.SetupProject()
 			ns := oc.Namespace()
 
-			execPod := exutil.CreateCentosExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
+			execPod := exutil.CreateUbiExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", nil)
 			defer func() {
 				oc.AdminKubeClient().CoreV1().Pods(ns).Delete(context.Background(), execPod.Name, *metav1.NewDeleteOptions(1))
 			}()
@@ -429,6 +420,37 @@ var _ = g.Describe("[sig-instrumentation] Prometheus", func() {
 			}
 			helper.RunQueries(queries, oc, ns, execPod.Name, url, bearerToken)
 		})
+		g.It("should provide named network metrics", func() {
+			oc.SetupProject()
+			ns := oc.Namespace()
+
+			cs, err := newDynClientSet()
+			o.Expect(err).NotTo(o.HaveOccurred())
+			err = addNetwork(cs, "secondary", ns)
+			o.Expect(err).NotTo(o.HaveOccurred())
+
+			defer func() {
+				err := removeNetwork(cs, "secondary", ns)
+				o.Expect(err).NotTo(o.HaveOccurred())
+			}()
+
+			execPod := exutil.CreateUbiExecPodOrFail(oc.AdminKubeClient(), ns, "execpod", func(pod *v1.Pod) {
+				pod.Annotations = map[string]string{
+					"k8s.v1.cni.cncf.io/networks": "secondary",
+				}
+			})
+
+			defer func() {
+				oc.AdminKubeClient().CoreV1().Pods(ns).Delete(context.Background(), execPod.Name, *metav1.NewDeleteOptions(1))
+			}()
+
+			g.By("verifying named metrics keys")
+			queries := map[string]bool{
+				fmt.Sprintf(`pod_network_name_info{pod="%s",namespace="%s",interface="eth0"} == 0`, execPod.Name, execPod.Namespace):                true,
+				fmt.Sprintf(`pod_network_name_info{pod="%s",namespace="%s",network_name="%s/secondary"} == 0`, execPod.Name, execPod.Namespace, ns): true,
+			}
+			helper.RunQueries(queries, oc, ns, execPod.Name, url, bearerToken)
+		})
 	})
 })
 
